@@ -1,7 +1,8 @@
 import pandas as pd
 import numpy as np
 class CellAutomatRegression:
-    def __init__(self, data:pd.DataFrame, 
+    def __init__(self, 
+                data:pd.DataFrame, 
                 name_item = None, 
                 name_user = None,
                 number_items:int = None,
